/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * You may not modify, use, reproduce, or distribute this
 * software except in compliance with the terms of the License at:
 *
 *   http://developer.sun.com/berkeley_license.html
 *
 */

package com.sun.rave.poweredby;

import java.util.Locale;
import java.util.ResourceBundle;
import javax.faces.component.UIComponentBase;
import javax.faces.el.ValueBinding;

/**
 *
 * @author mbohm
 */
public abstract class PoweredBy extends UIComponentBase {
    
     /**
      * <p>The standard component family for this component.</p>
      */
    public static final String COMPONENT_FAMILY = "com.sun.rave.poweredby.PoweredBy";  //NOI18N
    
    /**
     * <p>The standard renderer type for this component.</p>
     */
    public static final String RENDERER_TYPE = "com.sun.rave.poweredby.PoweredByRenderer";  //NOI18N
    
    
    // --------------------------------------------------------------Constructors
    
    public PoweredBy() {
        super();
        setRendererType(RENDERER_TYPE);
    }
    
    
    // -------------------------------------------------------------- Family
    
    /**
     * <p>Return the component family for this component.</p>
     */
    public String getFamily() {
        return (COMPONENT_FAMILY);
    }
    
    // -------------------------------------------------------------- Properties
    
    // style
    private String style = null;
    
    /**
     * <p>CSS style(s) to be applied when this component is rendered.</p>
     */
    public String getStyle() {
        if (this.style != null) {
            return this.style;
        }
        ValueBinding vb = getValueBinding("style"); //NOI18N
        if (vb != null) {
            return (String) vb.getValue(getFacesContext());
        }
        return null;
    }
    
    /**
     * <p>CSS style(s) to be applied when this component is rendered.</p>
     * @see #getStyle()
     */
    public void setStyle(String style) {
        this.style = style;
    }
    
    // styleClass
    private String styleClass = null;
    
    /**
     * <p>CSS style class(es) to be applied when this component is rendered.</p>
     */
    public String getStyleClass() {
        if (this.styleClass != null) {
            return this.styleClass;
        }
        ValueBinding vb = getValueBinding("styleClass");  //NOI18N
        if (vb != null) {
            return (String) vb.getValue(getFacesContext());
        }
        return null;
    }
    
    /**
     * <p>CSS style class(es) to be applied when this component is rendered.</p>
     * @see #getStyleClass()
     */
    public void setStyleClass(String styleClass) {
        this.styleClass = styleClass;
    }
    
    protected ResourceBundle getBundle() {
        ResourceBundle bundle = ResourceBundle.getBundle(
                "com.sun.rave.poweredby.util.Bundle",
                Locale.getDefault(),
                PoweredBy.class.getClassLoader());
        return bundle;
    }
    
    // -------------------------------------------------------------- Abstract Methods
    
     /** 
      * <p>Get the relative image URL within the jar.</p>
      */
      protected abstract String getImageJarPath();
      
      /**
       * <p>Get the destination URL.</p>
       */
      protected abstract String getDestinationUrl();
      
      /**
       * <p>Get the image width.</p>
       */
      protected abstract int getImageWidth();
      
      /**
       * <p>Get the image height.</p>
       */
      protected abstract int getImageHeight();
      
      /**
       * <p>Get the image alt text.</p>
       */
       protected abstract String getImageAlt();
}
