/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * You may not modify, use, reproduce, or distribute this
 * software except in compliance with the terms of the License at:
 *
 *   http://developer.sun.com/berkeley_license.html
 *
 */

package com.sun.rave.poweredby;


import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

import java.io.IOException;

import com.sun.rave.poweredby.util.BaseRenderer;
import java.beans.Beans;
import org.apache.shale.remoting.XhtmlHelper;
import org.apache.shale.remoting.Mechanism;

/**
 * <p>Render our associated {@link PoweredBy}.
 * </p>
 * @author mbohm
 */
public class PoweredByRenderer extends BaseRenderer {
    
    /**
     * <p>Stateless helper bean to manufacture resource linkages.</p>
     */
    private static XhtmlHelper helper = new XhtmlHelper();
    
    public void encodeEnd(FacesContext context, UIComponent component)
    throws IOException {

        PoweredBy poweredby = null;
        if (component instanceof PoweredBy) {
            poweredby = (PoweredBy)component;
        } else {
            System.err.println("PoweredByRenderer.encodeBegin: expected type " + PoweredBy.class + " but found " + component.getClass());  //NOI18N
            System.err.println("PoweredByRenderer.encodeBegin: class loader hierarchy, starting with PoweredBy.class.getClassLoader():");  //NOI18N
            ClassLoader cl = PoweredBy.class.getClassLoader();
            while(cl != null) {
                System.err.println(cl);
                cl = cl.getParent();
            }
            System.err.println();
            System.err.println("PoweredByRenderer.encodeBegin: class loader hierarchy, starting with component.getClass().getClassLoader():");  //NOI18N
            cl = component.getClass().getClassLoader();
            while(cl != null) {
                System.err.println(cl);
                cl = cl.getParent();
            }
            System.err.println();
        }
        
        if (poweredby == null) {
            throw new NullPointerException();
        }
        
        ResponseWriter writer = context.getResponseWriter();
        
        writer.startElement("a", component);  //NOI18N
        String clientId = component.getClientId(context);
        writer.writeAttribute("id", clientId, "id");  //NOI18N
        String style = poweredby.getStyle();
        String styleClass = poweredby.getStyleClass();
        if (style != null) {
            writer.writeAttribute("style", style, "style");  //NOI18N
        }
        if (styleClass != null) {
            writer.writeAttribute("class", styleClass, "styleClass");  //NOI18N
        }
        String destinationUrl = poweredby.getDestinationUrl();
        writer.writeAttribute("href", destinationUrl, null);  //NOI18N
        
        writer.startElement("img", null);   //NOI18N
        String jarPath = poweredby.getImageJarPath();
        String imageUrl = getImageUrl(context, poweredby, jarPath);
        writer.writeAttribute("src", imageUrl, null);    //NOI18N
        writer.writeAttribute("width", String.valueOf(poweredby.getImageWidth()), null);    //NOI18N
        writer.writeAttribute("height", String.valueOf(poweredby.getImageHeight()), null);    //NOI18N
        writer.writeAttribute("alt", poweredby.getImageAlt(), null);    //NOI18N
        writer.writeAttribute("border", "0", null); //NOI18N
        writer.endElement("img");   //NOI18N
        
        writer.endElement("a"); //NOI18N
        writer.write("\n"); //NOI18N
    }
    
    private String getImageUrl(FacesContext context, UIComponent component, String jarPath) {
        if (Beans.isDesignTime()) {
            return component.getClass().getResource(jarPath).toString();
        }
        else {
            return helper.mapResourceId(context, Mechanism.CLASS_RESOURCE, jarPath);
        }
    }
    
}
