/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * You may not modify, use, reproduce, or distribute this
 * software except in compliance with the terms of the License at:
 *
 *   http://developer.sun.com/berkeley_license.html
 *
 */

package com.sun.rave.poweredby.creator;

import com.sun.rave.poweredby.PoweredBy;
import java.util.ResourceBundle;
import javax.faces.context.FacesContext;

/**
 *
 * @author mbohm
 */
public class PoweredByCreator extends PoweredBy {
    
    private static final String DESTINATION_URL = 
            "http://developers.sun.com/prodtech/javatools/jscreator/index.jsp?cid=181321";   //NOI18N
    
    private static final String HORIZONTAL_ROUNDED_IMAGE =
            "/META-INF/creator/images/c_hori_round.gif";   //NOI18N
    
    private static final String HORIZONTAL_SQUARE_IMAGE =
            "/META-INF/creator/images/c_hori_squar.gif";   //NOI18N
    
    private static final String VERTICAL_ROUNDED_IMAGE =
            "/META-INF/creator/images/c_vert_round.gif";   //NOI18N
    
    private static final String VERTICAL_SQUARE_IMAGE =
            "/META-INF/creator/images/c_vert_squar.gif";   //NOI18N
    
    private static final int HORIZONTAL_IMAGE_WIDTH = 182;
    
    private static final int HORIZONTAL_IMAGE_HEIGHT = 34;
    
    private static final int VERTICAL_IMAGE_WIDTH = 103;
    
    private static final int VERTICAL_IMAGE_HEIGHT = 68;
    
    // -------------------------------------------------------------- Properties
    
    // tall
    private boolean tall = false;
    
    /**
     * <p>Get the flag indicating whether the words within the image will 
     * be stacked vertically, making the image taller. 
     * False by default.</p>
     */
    public boolean isTall() {
        return this.tall;
    }
    
    /**
     * <p>Set the flag indicating whether the words within the image will 
     * be stacked vertically, making the image taller. 
     * </p>
     */
    public void setTall(boolean tall) {
        this.tall = tall;
    }
    
    //rounded
    private boolean rounded = true;
    
    /**
     * <p>Get the flag indicating whether the image will be displayed
     * with rounded corners. True by default.</p>
     */
     public boolean isRounded() {
         return this.rounded;
     }
     
    /**
     * <p>Set the flag indicating whether the image will be displayed
     * with rounded corners.</p>
     */
     public void setRounded(boolean rounded) {
         this.rounded = rounded;
     }
     
     // ----------------------------------------------------- Implement abstract methods from PoweredBy
     
    protected String getImageJarPath() {
        if (isTall()) {
            if (isRounded()) {
                return VERTICAL_ROUNDED_IMAGE;
            }
            else {
                return VERTICAL_SQUARE_IMAGE;
            }
        }
        else {
            if (isRounded()) {
                return HORIZONTAL_ROUNDED_IMAGE;
            }
            else {
                return HORIZONTAL_SQUARE_IMAGE;
            }
        }
    }
     
    /**
    * <p>Get the destination URL.</p>
    */
    protected String getDestinationUrl() {
        return DESTINATION_URL;
    }

    /**
    * <p>Get the image width.</p>
    */
    protected int getImageWidth() {
        if (isTall()) {
            return VERTICAL_IMAGE_WIDTH;
        }
        else {
            return HORIZONTAL_IMAGE_WIDTH;
        }
    }

    /**
    * <p>Get the image height.</p>
    */
    protected int getImageHeight() {
        if (isTall()) {
            return VERTICAL_IMAGE_HEIGHT;
        }
        else {
            return HORIZONTAL_IMAGE_HEIGHT;
        }
    }

    /**
    * <p>Get the image alt text.</p>
    */
    protected String getImageAlt() {
        ResourceBundle bundle = getBundle();
        return bundle.getString("PoweredByCreator.alt"); //NOI18N
    }
    
    // ----------------------------------------------------- StateHolder Methods
    /**
     * <p>Return the state to be saved for this component.
     *
     * @param context <code>FacesContext</code> for the current request
     */
    public Object saveState(FacesContext context) {
        Object values[] = new Object[5];
        values[0] = super.saveState(context);
        values[1] = getStyle();
        values[2] = getStyleClass();
        values[3] = new Boolean(isTall());
        values[4] = new Boolean(isRounded());
        return (values);
    }
    
    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
        setStyle((String)values[1]);
        setStyleClass((String)values[2]);
        setTall(((Boolean)values[3]).booleanValue());
        setRounded(((Boolean)values[4]).booleanValue());
    }
    
}
