/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * You may not modify, use, reproduce, or distribute this
 * software except in compliance with the terms of the License at:
 *
 *   http://developer.sun.com/berkeley_license.html
 *
 */

package com.sun.rave.poweredby.enterprise;

import com.sun.rave.poweredby.creator.PoweredByCreator;
import java.util.ResourceBundle;

/**
 *
 * @author mbohm
 */
public class PoweredByEnterprise extends PoweredByCreator {
    
    private static final String DESTINATION_URL = 
            "http://developers.sun.com/prodtech/javatools/jsenterprise/index.jsp?cid=181322";   //NOI18N
    
    private static final String HORIZONTAL_ROUNDED_IMAGE =
            "/META-INF/enterprise/images/e_hori_round.gif";   //NOI18N
    
    private static final String HORIZONTAL_SQUARE_IMAGE =
            "/META-INF/enterprise/images/e_hori_squar.gif";   //NOI18N
    
    private static final String VERTICAL_ROUNDED_IMAGE =
            "/META-INF/enterprise/images/e_vert_round.gif";   //NOI18N
    
    private static final String VERTICAL_SQUARE_IMAGE =
            "/META-INF/enterprise/images/e_vert_squar.gif";   //NOI18N
    
    private static final int HORIZONTAL_IMAGE_WIDTH = 195;
    
    private static final int HORIZONTAL_IMAGE_HEIGHT = 34;
    
    private static final int VERTICAL_IMAGE_WIDTH = 116;
    
    private static final int VERTICAL_IMAGE_HEIGHT = 68;
    
     // ----------------------------------------------------- Implement abstract methods from PoweredBy
    
    protected String getImageJarPath() {
        if (isTall()) {
            if (isRounded()) {
                return VERTICAL_ROUNDED_IMAGE;
            }
            else {
                return VERTICAL_SQUARE_IMAGE;
            }
        }
        else {
            if (isRounded()) {
                return HORIZONTAL_ROUNDED_IMAGE;
            }
            else {
                return HORIZONTAL_SQUARE_IMAGE;
            }
        }
    }
     
    /**
    * <p>Get the destination URL.</p>
    */
    protected String getDestinationUrl() {
        return DESTINATION_URL;
    }
    
    /**
    * <p>Get the image width.</p>
    */
    protected int getImageWidth() {
        if (isTall()) {
            return VERTICAL_IMAGE_WIDTH;
        }
        else {
            return HORIZONTAL_IMAGE_WIDTH;
        }
    }

    /**
    * <p>Get the image height.</p>
    */
    protected int getImageHeight() {
        if (isTall()) {
            return VERTICAL_IMAGE_HEIGHT;
        }
        else {
            return HORIZONTAL_IMAGE_HEIGHT;
        }
    }
    
    /**
    * <p>Get the image alt text.</p>
    */
    protected String getImageAlt() {
        ResourceBundle bundle = getBundle();
        return bundle.getString("PoweredByEnterprise.alt"); //NOI18N
    }
    
    //(Properties are inherited)
    //(StateHolder behavior is inherited)
    
}
